@@ -5,7 +5,7 @@ from urllib.parse import quote_plus
 from bson.objectid import ObjectId
 import os
 from flask_login import LoginManager,login_user,UserMixin,login_required,logout_user,current_user
-from settings import SECRET_KEY,MONGO_URI, EMAIL_USER, MONGO_PASSWORD, MONGO_USERNAME
+from settings import SECRET_KEY,MONGO_URI, EMAIL_USER, MONGO_PASSWORD, MONGO_USERNAME, COGNITO_CLIENT_ID, COGNITO_CLIENT_SECRET
 from utils import send_email, get_videos
 from werkzeug.middleware.proxy_fix import ProxyFix
 
@@ -13,8 +13,6 @@ from werkzeug.middleware.proxy_fix import ProxyFix
 
 app = Flask(__name__)
 app.secret_key = SECRET_KEY  # Secure your secret key with an environment variable 
-# 🔐 Let Flask correctly detect HTTPS and domain from proxy headers
-app.wsgi_app = ProxyFix(app.wsgi_app, x_proto=1, x_host=1)
 ### app.secret_key = SECRET_KEY isn’t an import at all—it’s just an assignment
 login_manager = LoginManager()
 
@@ -272,19 +270,24 @@ oauth = OAuth(app)
 oauth.register(
   name='oidc',
   authority='https://cognito-idp.us-east-1.amazonaws.com/us-east-1_TZVykdVvG',
-  client_id='1lc7qso1g3lr9kqbr0nb0jktbs',
-  client_secret='1f1qa6rf66549cta1uqpamjpjqt06ne3agvlgou638e56kmt8dve',
+  client_id= COGNITO_CLIENT_ID,
+  client_secret=COGNITO_CLIENT_SECRET,    
   server_metadata_url='https://cognito-idp.us-east-1.amazonaws.com/us-east-1_TZVykdVvG/.well-known/openid-configuration',
   client_kwargs={'scope': 'phone openid email'}
 )
 ################################################
 
-#  Configure a login route to direct to Amazon Cognito managed login for authentication with a redirect to an authorize route.
 @app.route('/login/cognito')
 def login_cognito():
     session.pop('user', None)
-    redirect_uri = url_for('authorize', _external=True)
-    print("🧭 Redirect URI being used:", redirect_uri)  # <--- add this
+
+    # Determine redirect URI based on environment
+    if '1beto.com' in request.host:
+        redirect_uri = 'https://1beto.com/authorize'  # force HTTPS for production
+    else:
+        redirect_uri = url_for('authorize', _external=True)  # use localhost in dev
+
+    print("🧭 Redirect URI being used:", redirect_uri)
     return oauth.oidc.authorize_redirect(
         redirect_uri,
         prompt='login'
@@ -293,7 +296,6 @@ def login_cognito():
 
 
 
-
 # The OAuth module collects the access token and retrieves user data from the Amazon Cognito userInfo endpoint. Configure an authorize route to handle the access token and user data after authentication.
 @app.route('/authorize')
 def authorize():
@@ -303,11 +305,26 @@ def authorize():
     return redirect(url_for('home'))  # ✅ Fixed: 'home' matches your defined route
 
 
-# Configure a logout route that erases user session data.
+
+
+from flask import request
+
 @app.route('/logout/cognito')
-def logout_cognito():  # ✅ Renamed to avoid conflict
+def logout_cognito():
     session.pop('user', None)
-    return redirect(url_for('home'))  # 🔁 Also change to 'home' if 'index' doesn't exist
+
+    cognito_domain = 'https://us-east-1tzvykdvvg.auth.us-east-1.amazoncognito.com'
+    client_id = '1lc7qso1g3lr9kqbr0nb0jktbs'
+
+    # Ensure trailing slash and domain match Cognito settings exactly
+    if '1beto.com' in request.host:
+        logout_redirect_uri = 'https://1beto.com/'  # ✅ Matches Cognito config
+    else:
+        logout_redirect_uri = 'http://localhost:50/'  # ✅ Matches Cognito config for local
+
+    return redirect(
+        f"{cognito_domain}/logout?client_id={client_id}&logout_uri={logout_redirect_uri}"
+    )
 
 
 
